Learn R Programming

microSTASIS (version 0.1.0)

paired_times: Generate a subset matrix with paired times.

Description

Generate a subset matrix with paired times.

Usage

paired_times(data, first, second, common)

Arguments

data

input matrix with each rowname including an ID, a common pattern and a sampling time.

first

pattern associated with the first of the two sampling times.

second

pattern associated with the second of the two sampling times.

common

pattern that separates the ID and the sampling time.

Value

A matrix with the same number of columns as input and the samples from both samples times.

Examples

Run this code
# NOT RUN {
t1_t2 <- paired_times(data = clr, first = "_1",
                      second = "_25", common = "_0_")
# }

Run the code above in your browser using DataLab