powered by
Generate a subset matrix with paired times.
paired_times(data, first, second, common)
input matrix with each rowname including an ID, a common pattern and a sampling time.
pattern associated with the first of the two sampling times.
pattern associated with the second of the two sampling times.
pattern that separates the ID and the sampling time.
A matrix with the same number of columns as input and the samples from both samples times.
# NOT RUN { t1_t2 <- paired_times(data = clr, first = "_1", second = "_25", common = "_0_") # }
Run the code above in your browser using DataLab